==> driza-0.6.0.tar.gz: driza-0.6/Driza/dialogs/dbuscar.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#pushButton1: Buscar
#pushButton2: Cancelar


from Driza.ui.dialogos.uidbuscar import DialogoBuscar
from qt import *


class DBuscar(DialogoBuscar):
	"""Dialogo de busqueda 
	Busca cadenas de texto introducidas por el usuario en la tabla que este activa """

	def __init__(self,parent=None,name=None,modal=0,fl=0):
		"""Inicializacion, llama a la funcion que define las conexiones"""
		DialogoBuscar.__init__(self,parent,name,modal,fl)
		#VARIABLES PRIVADAS
		self.__ultimabusqueda=""
		self.__conexiones()

	#FUNCIONES PRIVADAS

	def __buscar(self):
		""" Funcion busca la cadena de texto introducida por el usuario en la tabla que este activa, seleccionando el primer registro válido que encuentre"""
		if self.parent().tabWidget2.currentPageIndex() == 0: tablaactual=self.parent().table1
		else: tablaactual=self.parent().table2
		x=tablaactual.currentRow()
		y=tablaactual.currentColumn()
		textoabuscar=self.lineEdit1.text().latin1()
		exito=False
		if x<0:x=0
		if y<0:y=0
		#Si es la misma busqueda que la última vez, incrementamos la fila
		if self.__ultimabusqueda==textoabuscar:
			x+=1
		else:
			self.__ultimabusqueda=textoabuscar
		for j in range(y,tablaactual.numCols()):
			for i in range(x,tablaactual.numRows()):
				if (cmp(tablaactual.text(i,j).latin1(),textoabuscar)==0) and not exito:
					tablaactual.clearSelection()
					tablaactual.setCurrentCell(i,j)
					exito=True
		#No ha encontrado resultado
		if not exito:
			#Comienza la búsqueda por el principio
			rc = QMessageBox.warning(self,'Atencion', 'No he encontrado nada', 'Continuar desde el principio','Salir','',0,1 )
			if rc==0:
				for j in range(y+1):
					for i in range(x+1):
						if (cmp(tablaactual.text(i,j).latin1(),textoabuscar)==0) and not exito:
							tablaactual.clearSelection()
							tablaactual.setCurrentCell(i,j)
							exito=True
				if not exito:
					rc = QMessageBox.warning(self,'Atencion', 'No he encontrado nada', 'Otra busqueda','Salir','',0,1 )
					self.lineEdit1.clear()

				
			else:
				self.reject()


	def __conexiones(self):
		"""Función que define las conexiones entre elementos de la interfaz y sus SLOTS"""
		self.connect(self.pushButton1,SIGNAL("clicked()"),self.__buscar)
		self.connect(self.pushButton2,SIGNAL("clicked()"),self.reject)

==> driza-0.6.4.tar.gz: driza-0.6.4/Driza/dialogs/dbuscar.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#pushButton1: Buscar
#pushButton2: Cancelar


from Driza.ui.dialogos.uidbuscar import DialogoBuscar
from qt import *


class DBuscar(DialogoBuscar):
	"""Dialogo de busqueda 
	Busca cadenas de texto introducidas por el usuario en la tabla que este activa """

	def __init__(self,parent=None,name=None):
		"""Inicializacion, llama a la funcion que define las conexiones"""
		DialogoBuscar.__init__(self,parent,name,0,0)
		#VARIABLES PRIVADAS
		self.__ultimabusqueda=""
		self.__conexiones()

	#FUNCIONES PRIVADAS

	def __buscar(self):
		""" Funcion busca la cadena de texto introducida por el usuario en la tabla que este activa, seleccionando el primer registro válido que encuentre"""
		if self.parent().grid.currentPageIndex() == 0: tablaactual=self.parent().grid.table1
		else: tablaactual=self.parent().grid.table2
		x=tablaactual.currentRow()
		y=tablaactual.currentColumn()
		textoabuscar=self.lineEdit1.text().latin1()
		exito=False
		if x<0:x=0
		if y<0:y=0
		#Si es la misma busqueda que la última vez, incrementamos la fila
		if self.__ultimabusqueda==textoabuscar:
			x+=1
		else:
			self.__ultimabusqueda=textoabuscar
		for j in range(y,tablaactual.numCols()):
			for i in range(x,tablaactual.numRows()):
				if (cmp(tablaactual.text(i,j).latin1(),textoabuscar)==0) and not exito:
					tablaactual.clearSelection()
					tablaactual.setCurrentCell(i,j)
					exito=True
		#No ha encontrado resultado
		if not exito:
			#Comienza la búsqueda por el principio
			rc = QMessageBox.warning(self,'Atencion', 'No he encontrado nada', 'Continuar desde el principio','Salir','',0,1 )
			if rc==0:
				for j in range(y+1):
					for i in range(x+1):
						if (cmp(tablaactual.text(i,j).latin1(),textoabuscar)==0) and not exito:
							tablaactual.clearSelection()
							tablaactual.setCurrentCell(i,j)
							exito=True
				if not exito:
					rc = QMessageBox.warning(self,'Atencion', 'No he encontrado nada', 'Otra busqueda','Salir','',0,1 )
					self.lineEdit1.clear()

				
			else:
				self.reject()


	def __conexiones(self):
		"""Función que define las conexiones entre elementos de la interfaz y sus SLOTS"""
		self.connect(self.pushButton1,SIGNAL("clicked()"),self.__buscar)
		self.connect(self.pushButton2,SIGNAL("clicked()"),self.reject)
